/*
 * Copyright (c) 2008  Yuri Chernyavsky
 * Copyright (c) 2007  Gregor Richards
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#ifndef SMV_ENCODE_FRONTEND_H
#define SMV_ENCODE_FRONTEND_H

/* Default parameter values */
#define DEFAULT_PARAM_W 96
#define DEFAULT_PARAM_H 128
#define DEFAULT_PARAM_FR 10
#define DEFAULT_PARAM_FPJ 5
#define DEFAULT_PARAM_Q 41
#define DEFAULT_PARAM_ROTATE 1

typedef unsigned char msg_tag_t;
typedef unsigned char msg_content_t;

typedef struct {
  msg_tag_t tag;
  msg_content_t content;
} msg_t;

typedef enum {
  phase_start = 0,
  phase_start_percentage = 1,
  phase_end = 2,
  error = 3,
  percentage = 4,
  alive = 5,
  hello = 6,
  interrupted = 7,
  success = 8
} tag_t;

typedef enum {
  phase_decode = 0,
  phase_frames = 1,
  phase_tile = 2,
  phase_audio = 3,
  phase_combine = 4
} phase_t;

typedef enum {
  err_input_file = 0,
  err_output_file_not_writable = 2,
  err_bad_parameter = 3,
  err_decode = 4,
  err_frames = 5,
  err_tile = 6,
  err_audio = 7,
  err_combine = 8,
  err_unexpected = 9
} err_t;

#define EXIT_STATUS_ERROR 1
#define EXIT_STATUS_INTERRUPTED 2
#define EXIT_STATUS_NO_RUN 3

#endif
